@@ -61,7 +61,7 @@ This application implements the following features:
 """
 
 # This is injected automatically at release time
-__exact_version__ = 'v3.7'
+__exact_version__ = 'v3.8'
 
 import logging
 
@@ -189,6 +189,8 @@ def main(global_config, **settings):
     config.add_route('lit_club', '/lit/club/{guid}')
     config.add_route('lit_latest', '/lit/latest')
     config.add_route('lit_player', '/lit/player/{guid}')
+    config.add_route('lit_player_opponent', '/lit/player/{guid}/{opponent}')
+    config.add_route('lit_player_matches', '/lit/matches/{guid}')
     config.add_route('lit_players', '/lit/players')
     config.add_route('lit_players_list', '/lit/players/{letter}/{country}')
     config.add_route('lit_rating', '/lit/rating/{guid}')
@@ -213,6 +215,7 @@ def main(global_config, **settings):
 
     config.add_route('svg_playersdist', '/svg/playersdist')
     config.add_route('svg_ratingchart', '/svg/ratingchart/{id}')
+    config.add_route('svg_player_opponent', '/svg/player/{guid}/{opponent}')
 
     config.scan(ignore='sol.tests')
 
