@@ -80,26 +80,28 @@ class Championship(GloballyUnique, Base):
         info=dict(label=N_('Prizes'),
                   hint=N_('Method used to assign final prizes.'),
                   dictionary=dict(
-                      asis=N_('Simple tourneys, no special prizes'),
+                      asis=N_('No final prizes'),
                       fixed=N_('Fixed prizes: 18,16,14,13...'),
                       fixed40=N_('Fixed prizes: 1000,900,800,750...'),
-                      millesimal=N_('Classic millesimal prizes'))))
+                      millesimal=N_('Classic millesimal prizes'),
+                      centesimal=N_('Centesimal prizes'))))
     """Kind of prize-giving.
 
     This is used to determine which method will be used to assign
     final prizes. It may be:
 
     `asis`
-      means that the final prize is the same as the competitor's points;
+      means that the final prize is a plain integer number, monotonically decreasing down to 1
+      starting from num-of-competitors: this is meant to give the chance of swapping
+      competitors positions after tournament's final rounds, the `final prize` column won't
+      even show up in the final ranking printout;
 
     `fixed`
-      means the usual way, that is 18 points to the winner, 16 to the
-      second, 14 to the third, 13 to the fourth, ..., 1 point to the
-      16th, 0 points after that;
+      means the usual way, that is 18 points to the winner, 16 to the second, 14 to the third,
+      13 to the fourth, ..., 1 point to the 16th, 0 points after that;
 
     `fixed40`
-      similar to `fixed`, but applied to best fourty scores starting
-      from 1000:
+      similar to `fixed`, but applied to best fourty scores starting from 1000:
 
         1. 1000
         2. 900
@@ -143,8 +145,12 @@ class Championship(GloballyUnique, Base):
         40. 1
 
     `millesimal`
-      is the classic method, that distributes a multiple of
-      1000/num-of-competitors."""
+      is the classic method, that distributes a multiple of 1000/num-of-competitors;
+
+    `centesimal`
+      assigns 100 to the first ranked competitor, 1 to the last, linear interpolation
+      to the other competitors.
+    """
 
     skipworstprizes = Column(
         smallint_t,
@@ -225,20 +231,21 @@ class Championship(GloballyUnique, Base):
         Results in a tuple of two items, the first being a list of two slots tuples,
         respectively the date and the guid of a tourney, the second a list of tuples, sorted by
         total prize: each tuple contains five items, a tuple of players, their total prize, a
-        list of their prizes sorted by date of event, the number of prizes and finally `None`
-        or a list of skipped prizes.
+        list of their prizes sorted by date of event, the number of prizes and finally either
+        `None` or a list of skipped prizes.
         """
 
         dates = []
         allprizes = {}
         for t in self.tourneys:
             if t.prized and (limit is None or t.date>=limit):
+                prizes = t.championship.prizes
                 dates.append((t.date, t.guid))
                 for c in t.competitors:
                     if not onlywomen or c.player1.sex == 'F':
                         players = (c.player1, c.player2, c.player3, c.player4)
                         prizes = allprizes.setdefault(players, {})
-                        prize = c.prize
+                        prize = c.points if prizes == 'asis' else c.prize
                         prizes[t.date] = prize
         dates.sort()
 
@@ -282,8 +289,7 @@ class Championship(GloballyUnique, Base):
             simple['owner'] = serializer.addPlayer(self.owner)
         simple['description'] = self.description
         simple['prizes'] = self.prizes
-        if self.couplings:
-            simple['couplings'] = self.couplings
+        simple['couplings'] = self.couplings
         simple['skipworstprizes'] = self.skipworstprizes
         simple['playersperteam'] = self.playersperteam
         simple['closed'] = self.closed
