@@ -731,13 +731,15 @@ class Tourney(GloballyUnique, Base):
             self.rating.recompute(self.date)
 
     def _assignAsisPrizes(self):
-        "Assign player's points as final prizes."
+        "Assign decreasing integer numbers as final prizes, down to 1 to the last competitor."
 
+        prize = len(self.ranking)
         for c in self.ranking:
-            c.prize = c.points
+            c.prize = prize
+            prize -= 1
 
     def _assignFixedPrizes(self, prizes=None):
-        "Assign fixed prizes to the first 16 players."
+        "Assign fixed prizes to the first 16 competitors."
 
         if prizes is None:
             # This is what Scarry used to do.
@@ -751,7 +753,7 @@ class Tourney(GloballyUnique, Base):
             c.prize = prize
 
     def _assignFixed40Prizes(self):
-        "Assign fixed prizes to the first 40 players."
+        "Assign fixed prizes to the first 40 competitors."
 
         # This is the Francesco Beltrami's series of prizes, used
         # in the 2009-2010 italian national championship.
@@ -773,7 +775,20 @@ class Tourney(GloballyUnique, Base):
             c.prize = prize
             prize -= fraction
 
+    def _assignCentesimalPrizes(self):
+        "Assigns 100 to the winner, 1 to the last, linear interpolation to the others."
+
+        # This was suggested by Carlito
+
+        ranking = self.ranking
+        prize = 100.0
+        fraction = (prize - 1) / (len(ranking) - 1)
+        for c in ranking:
+            c.prize = round(prize, 2)
+            prize -= fraction
+
     def resetPrizes(self):
+
         """Reset assigned final points."""
 
         for c in self.competitors:
