@@ -144,54 +144,153 @@ Ext.define('SoL.view.Matches', {
     ],
 
     statics: {
-        ordinals: [
-            '',
-            _('the first'),
-            _('the second'),
-            _('the third'),
-            _('the fourth'),
-            _('the fifth'),
-            _('the sixth'),
-            _('the seventh'),
-            _('the eighth'),
-            _('the nineth'),
-            _('the tenth'),
-            _('the eleventh'),
-            _('the twelfth'),
-            _('the thirdteenth'),
-            _('the fourteenth'),
-            _('the fifteenth'),
-            _('the sixteenth')
-        ],
-
-        ordinalsp: [
-            '',
-            _('of the first'),
-            _('of the second'),
-            _('of the third'),
-            _('of the fourth'),
-            _('of the fifth'),
-            _('of the sixth'),
-            _('of the seventh'),
-            _('of the eighth'),
-            _('of the nineth'),
-            _('of the tenth'),
-            _('of the eleventh'),
-            _('of the twelfth'),
-            _('of the thirdteenth'),
-            _('of the fourteenth'),
-            _('of the fifteenth'),
-            _('of the sixteenth')
-        ],
-
         ordinal: function(num) {
-            var ordinals = SoL.view.Matches.ordinals;
-            return num>0 && num<ordinals.length ? ordinals[num] : num+'';
+            var r;
+
+            switch(num) {
+                case 1:
+                    r = _('the first');
+                    break;
+
+                case 2:
+                    r = _('the second');
+                    break;
+
+                case 3:
+                    r = _('the third');
+                    break;
+
+                case 4:
+                    r = _('the fourth');
+                    break;
+
+                case 5:
+                    r = _('the fifth');
+                    break;
+
+                case 6:
+                    r = _('the sixth');
+                    break;
+
+                case 7:
+                    r = _('the seventh');
+                    break;
+
+                case 8:
+                    r = _('the eighth');
+                    break;
+
+                case 9:
+                    r = _('the nineth');
+                    break;
+
+                case 10:
+                    r = _('the tenth');
+                    break;
+
+                case 11:
+                    r = _('the eleventh');
+                    break;
+
+                case 12:
+                    r = _('the twelfth');
+                    break;
+
+                case 13:
+                    r = _('the thirdteenth');
+                    break;
+
+                case 14:
+                    r = _('the fourteenth');
+                    break;
+
+                case 15:
+                    r = _('the fifteenth');
+                    break;
+
+                case 16:
+                    r = _('the sixteenth');
+                    break;
+
+                default:
+                    r = num+'';
+                    break;
+            }
+            return r;
         },
 
         ordinalp: function(num) {
-            var ordinals = SoL.view.Matches.ordinalsp;
-            return num>0 && num<ordinals.length ? ordinals[num] : num+'';
+            var r;
+            switch(num) {
+                case 1:
+                    r = _('of the first');
+                    break;
+
+                case 2:
+                    r = _('of the second');
+                    break;
+
+                case 3:
+                    r = _('of the third');
+                    break;
+
+                case 4:
+                    r = _('of the fourth');
+                    break;
+
+                case 5:
+                    r = _('of the fifth');
+                    break;
+
+                case 6:
+                    r = _('of the sixth');
+                    break;
+
+                case 7:
+                    r = _('of the seventh');
+                    break;
+
+                case 8:
+                    r = _('of the eighth');
+                    break;
+
+                case 9:
+                    r = _('of the nineth');
+                    break;
+
+                case 10:
+                    r = _('of the tenth');
+                    break;
+
+                case 11:
+                    r = _('of the eleventh');
+                    break;
+
+                case 12:
+                    r = _('of the twelfth');
+                    break;
+
+                case 13:
+                    r = _('of the thirdteenth');
+                    break;
+
+                case 14:
+                    r = _('of the fourteenth');
+                    break;
+
+                case 15:
+                    r = _('of the fifteenth');
+                    break;
+
+                case 16:
+                    r = _('of the sixteenth');
+                    break;
+
+                default:
+                    r = num+'';
+                    break;
+            }
+            return r;
         },
 
         getConfig: function(callback, errorcb, config) {
@@ -491,7 +590,6 @@ Ext.define('SoL.view.Matches', {
 
     filterOnTurn: function(turn) {
         var me = this;
-        var ordinalp = me.statics().ordinalp;
         var store = me.store;
         var tourney = me.module.tourney;
 
