@@ -47,6 +47,15 @@ class TestModels(TestCase):
         m = juri.matchesSummary()
         self.assertEqual(len(m), 3)
 
+        o = juri.opponents()
+        self.assertEqual(len(o), 3)
+
+        lele = s.query(models.Player) \
+               .filter_by(firstname=PlayerData.lele.firstname).one()
+
+        m = juri.opponentMatches(lele)
+        self.assertEqual(len(m), 2)
+
     def test_player_nickname_as_username(self):
         s = models.DBSession()
         danieled = s.query(models.Player) \
