@@ -81,7 +81,7 @@ def players(request, results):
                             hidden=True,
                             readOnly=True),
     player1Sex=dict(label=_('Sex'),
-                    hint=_('First player sex'),
+                    hint=_('First player sex.'),
                     hidden=True,
                     readOnly=True),
     player1FirstName=dict(label=_("First player's name"),
